@@ -14,7 +14,7 @@ from ..labwhere import (
 )
 
 
-def labwhere() -> LabwhereDataSource:
+def labwhere(**kwargs) -> LabwhereDataSource:
     labwhere = create_labwhere_datasource(
         labwhere_url=os.getenv('LABWHERE_URL', Defaults.LABWHERE_URL)
         + os.getenv('LABWHERE_API_PATH', Defaults.LABWHERE_API_PATH)
