@@ -6,6 +6,7 @@ import os
 
 from .defaults import Defaults
 from ..api_client import (
+    ApiDataSource,
     create_api_datasource
 )
 from ..core import (
@@ -13,7 +14,7 @@ from ..core import (
 )
 
 
-def tolqc(retries: int = 5):
+def tolqc(retries: int = 5, **kwargs) -> ApiDataSource:
     tolqc = create_api_datasource(
         api_url=os.getenv('TOLQC_URL', Defaults.TOLQC_URL)
         + os.getenv('TOLQC_API_PATH', Defaults.TOLQC_API_PATH),
